==> aws-java-sdk-ec2-1.10.25-sources.jar: com/amazonaws/services/ec2/model/NetworkInterfaceStatus.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * Network Interface Status
 */
public enum NetworkInterfaceStatus {
    
    Available("available"),
    Attaching("attaching"),
    InUse("in-use"),
    Detaching("detaching");

    private String value;

    private NetworkInterfaceStatus(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return NetworkInterfaceStatus corresponding to the value
     */
    public static NetworkInterfaceStatus fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("available".equals(value)) {
            return NetworkInterfaceStatus.Available;
        } else if ("attaching".equals(value)) {
            return NetworkInterfaceStatus.Attaching;
        } else if ("in-use".equals(value)) {
            return NetworkInterfaceStatus.InUse;
        } else if ("detaching".equals(value)) {
            return NetworkInterfaceStatus.Detaching;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-java-sdk-ec2-1.11.10-sources.jar: com/amazonaws/services/ec2/model/NetworkInterfaceStatus.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model;

/**
 * 
 */
public enum NetworkInterfaceStatus {

    Available("available"),
    Attaching("attaching"),
    InUse("in-use"),
    Detaching("detaching");

    private String value;

    private NetworkInterfaceStatus(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return NetworkInterfaceStatus corresponding to the value
     */
    public static NetworkInterfaceStatus fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        }

        for (NetworkInterfaceStatus enumEntry : NetworkInterfaceStatus.values()) {
            if (enumEntry.toString().equals(value)) {
                return enumEntry;
            }
        }

        throw new IllegalArgumentException("Cannot create enum from " + value
                + " value!");
    }
}
